@@ -2,30 +2,24 @@ from dataclasses import dataclass
 from pathlib import Path
 from typing import Any, Dict
 
-import tomli
-import tomli_w
+import tomlkit
 
 from zenconfig.base import BaseConfig, Format
 
 
 @dataclass
 class TOMLFormat(Format):
-    multiline_strings: bool = True
+    sort_keys: bool = False
 
     def load(self, path: Path) -> Dict[str, Any]:
-        return tomli.loads(path.read_text())
+        return tomlkit.loads(path.read_text())
 
     def dump(
         self,
         path: Path,
         config: Dict[str, Any],
     ) -> None:
-        path.write_text(
-            tomli_w.dumps(
-                config,
-                multiline_strings=self.multiline_strings,
-            )
-        )
+        path.write_text(tomlkit.dumps(config, sort_keys=self.sort_keys))
 
 
 BaseConfig.register_format(TOMLFormat(), ".toml")
