@@ -1,13 +1,30 @@
-from dataclasses import asdict, fields, is_dataclass
-from typing import Any, Dict, Type, TypeVar
+from dataclasses import Field, asdict, fields, is_dataclass
+from typing import (
+    Any,
+    ClassVar,
+    Dict,
+    Protocol,
+    Type,
+    TypeVar,
+)
+
+from typing_extensions import TypeGuard
 
 from zenconfig.base import BaseConfig, Schema
 from zenconfig.encoder import Encoder
 
-C = TypeVar("C")
+
+class DataclassInstance(Protocol):
+    __dataclass_fields__: ClassVar[Dict[str, Field]]
+
+
+C = TypeVar("C", bound=DataclassInstance)
 
 
 class DataclassSchema(Schema[C]):
+    def handles(self, cls: type) -> TypeGuard[Type[DataclassInstance]]:
+        return is_dataclass(cls)
+
     def from_dict(self, cls: Type[C], cfg: Dict[str, Any]) -> C:
         return _load_nested(cls, cfg)
 
@@ -15,7 +32,7 @@ class DataclassSchema(Schema[C]):
         return encoder(asdict(config))
 
 
-BaseConfig.register_schema(DataclassSchema(), is_dataclass)
+BaseConfig.register_schema(DataclassSchema())
 
 
 def _load_nested(cls: Type[C], cfg: Dict[str, Any]) -> C:
