@@ -1,5 +1,7 @@
 from typing import Any, Dict, Type, TypeVar
 
+from typing_extensions import TypeGuard
+
 from zenconfig.base import BaseConfig, Schema
 from zenconfig.encoder import Encoder
 
@@ -7,6 +9,9 @@ C = TypeVar("C", bound=dict)
 
 
 class DictSchema(Schema[C]):
+    def handles(self, cls: type) -> TypeGuard[Type[dict]]:
+        return issubclass(cls, dict)
+
     def from_dict(self, cls: Type[C], cfg: Dict[str, Any]) -> C:
         return cls(cfg)
 
@@ -14,4 +19,4 @@ class DictSchema(Schema[C]):
         return encoder(config)
 
 
-BaseConfig.register_schema(DictSchema(), lambda cls: issubclass(cls, dict))
+BaseConfig.register_schema(DictSchema())
